/* 
 * wave_mod.c
 *
 * wave module
 *
 * Copyright (C) 1998 Hermann Samso
 */

#include <stdlib.h>
#include <stdio.h>
#include <unistd.h>
#include <ncurses.h>
#include "types.h"
#include "delfin.h"
#include "display.h"
#include "wave.h"
#include "module.h"


INT channels = 1;

void WavInit(void) {
	if (trace_on)
		fprintf(stderr, "WavInit()\n");


	ModuleDisplay();
}


void WavExit(void) {
	if (trace_on)
		fprintf(stderr, "WavExit()\n");
}


void WavCtrl(INT input) {
	CHAR str[43];
	WAVE* wave;
	INT keys[] = {
		'w',		// next WAVE 
		'q', 		// previous WAVE
		'1',		// load 1 channel .raw WAVE
		'2',		// load 2 channel .raw WAVE
		'3',		// save 2 channel .raw WAVE
		'0',		// delete current WAVE
		'r',		// resize WAVE
		'b',		// roll to the left
		'v',
		'c',
		'x',
		'y',
		'n',		// roll to the right
		'm',
		',',
		'.',
		'-',
		' ',		// play sample
		'k'			// skip 44bytes header
	};


	if (trace_on)
		fprintf(stderr, "WavCtrl()\n");
		


	if (input == keys[0])
		WaveNext();
	else if (input == keys[1])
		WavePrevious();
	else if (input == keys[2] || input == keys[3]) {
		echo();
		notimeout(stdscr, TRUE);
		mvprintw(LINES-1, 0, "file:");
		mvgetnstr(LINES-1, 5, str, 42);
		notimeout(stdscr, FALSE);
		noecho();
		if (input == keys[2])
			WaveLoadRaw(str, 1);
		else
			WaveLoadRaw(str, 2);
		DisplayDelfin();
		ModuleDisplay();
	}
	else if (input == keys[4]) {
		echo();
		notimeout(stdscr, TRUE);
		mvprintw(LINES-1, 0, "file:");
		mvgetnstr(LINES-1, 5, str, 42);
		notimeout(stdscr, FALSE);
		noecho();
		WaveSaveRaw(str, WaveGet());
		DisplayDelfin();
		ModuleDisplay();
	}
	else if (input == keys[5])
		WaveDelete();
	else if (input == keys[6]) {
		echo();
		notimeout(stdscr, TRUE);
		mvprintw(LINES-1, 0, "size:");
		mvgetnstr(LINES-1, 5, str, 42);
		notimeout(stdscr, FALSE);
		noecho();
		WaveResize(atoi(str));
	}	
	// roll to left
	else if (input == keys[7])
		WaveRoll(-1);
	else if (input == keys[8])
		WaveRoll(-10);
	else if (input == keys[9])
		WaveRoll(-100);
	else if (input == keys[10])
		WaveRoll(-1000);
	else if (input == keys[11])
		WaveRoll(-10000);
	// roll to right
	else if (input == keys[12])
		WaveRoll(1);
	else if (input == keys[13])
		WaveRoll(10);
	else if (input == keys[14])
		WaveRoll(100);
	else if (input == keys[15])
		WaveRoll(1000);
	else if (input == keys[16])	
		WaveRoll(10000);
	else if (input == keys[17])
		WavePlaySelected();
	else if (input == keys[18]) {
		WaveRoll(-44);
		wave = WaveGet();
		WaveResize(wave->size-44);
	}
	else
		usleep(200);
		
	WaveDisplay();
}

void WavExec(void) {
	if (trace_on)
		fprintf(stderr, "WavExec()\n");
		
}



void WavDisplay(void) {
	if (trace_on)
		fprintf(stderr, "WavDisplay()\n");

	DisplayClearBottom();
	mvprintw(LINES-2, 0, "[%s]", wave_mod.name);
}




MODULE wave_mod = {
	NULL,			/* next MODULE  in list */
	NULL,			/* previous MODULE in list */
	"wave",
	"v1998.1.22 by Hermann Samso",
	WavInit,
	WavExit,
	WavCtrl,
	WavExec,
	WavDisplay
};

